/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.imageloader

import android.app.ActivityManager
import android.content.Context
import android.content.pm.ApplicationInfo
import android.os.StatFs
import androidx.core.content.ContextCompat
import java.io.File
import kotlin.math.max
import kotlin.math.min

internal fun calculateMemoryCacheSize(context: Context): Int {
    val am = ContextCompat.getSystemService(context, ActivityManager::class.java)
    val largeHeap = context.applicationInfo.flags and ApplicationInfo.FLAG_LARGE_HEAP != 0
    val memoryClass = if (largeHeap) am!!.largeMemoryClass else am!!.memoryClass
    // Target ~15% of the available heap.
    return (1024L * 1024L * memoryClass / 7).toInt()
}

internal fun calculateDiskCacheSize(dir: File): Long {
    var size = MIN_DISK_CACHE_SIZE

    try {
        val statFs = StatFs(dir.absolutePath)
        val blockCount = statFs.blockCountLong
        val blockSize = statFs.blockSizeLong
        val available = blockCount * blockSize
        size = (available / 50)
    } catch (ignored: IllegalArgumentException) {
    }
    return max(min(size, MAX_DISK_CACHE_SIZE), MIN_DISK_CACHE_SIZE)
}